import { useState, useEffect } from 'react'
import withLayout from '@/layout'
import { ScrollView } from '@tarojs/components'
import '@/assets/css/iconfont.css'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'
import { API_ITEMS_DETAIL, API_PROJECT_TREND_LIST, API_ACTIVITY_GROUP, API_LIVE_LIST, API_NEWS_LIST } from '@/constants/api'
import './index.scss'
import DetailBottom from './components/DetailBottom/index'
import Banner from './components/Banner/index'
import BasicInfo from './components/BasicInfo/index'
import SpecialPriceHouse from './components/SpecialPriceHouse/index'
import ProjectDynamic from './components/ProjectDynamic/index'
import PropertyConsultant from './components/PropertyConsultant/index'
import Periphery from './components/Periphery/index'
import HouseTypeIntro from './components/HouseTypeIntro/index'
import MarketingActivity from './components/MarketingActivity/index'
import LivingActivity from './components/LivingActivity/index'
import News from './components/News/index'
import Pictures from './components/Pictures/index'

export default withLayout((props) => {

  const user = useSelector(state => state.user)
  const [PersonId, setPersonId] = useState(null)
  const [DetailInfo, setDetailInfo] = useState({})
  const [ActivityList, setActivityList] = useState([])
  const [PictureList, setPictureList] = useState([])
  const [NewsList, setNewsList] = useState([])
  const [LiveList, setLiveList] = useState([])

  const [IsPull, setPull] = useState(false)
  const [PullTimer, setPullTimer] = useState(null)

  useEffect(() => {
    if (user?.userInfo?.person?.personId) {
      setPersonId(user.userInfo.person.personId)
    }
  }, [user])

  useEffect(() => {
    if (PersonId) {
      GetBuildingDetail()
      GetProjectTrendList()
      GetActivityList()
      GetLiveList()
      GetNewsList()
    }
  }, [PersonId])

  useEffect(() => {
    if (DetailInfo.buildingApartment) {
      const List = DetailInfo.buildingApartment.filter(item => item.apartmentType === 'photo')
      setPictureList(List.filter(item => item.buildingImgList.length > 0))
    }
  }, [DetailInfo])

  const GetBuildingDetail = () => { // 获取楼盘信息
    fetch({ url: `${API_ITEMS_DETAIL}/${props.router.params.id}`, method: 'get' }).then((res) => {
      setDetailInfo(res || {})
    })
  }

  const GetProjectTrendList = () => { // 获取项目动态
    fetch({ url: API_PROJECT_TREND_LIST, method: 'get' }).then((res) => {
      console.log(res)
    })
  }

  const GetActivityList = () => { // 获取活动列表
    fetch({ url: `${API_ACTIVITY_GROUP}?buildingId=${props.router.params.id}`, method: 'get' }).then((res) => {
      const ResArr = res || []
      setActivityList(ResArr.filter((item) => { return item.type !== 'help' && item.type !== 'group' }))
    })
  }

  const GetLiveList = () => { // 获取直播列表
    fetch({ url: `${API_LIVE_LIST}?buildingId=${props.router.params.id}`, method: 'get' }).then((res) => {
      let ResArr = res.records.slice(0, 2)
      if (ResArr.length === 1) {
        ResArr.push({})
      }
      setLiveList(ResArr || [])
    })
  }

  const GetNewsList = () => { // 获取资讯列表
    fetch({ url: `${API_NEWS_LIST}?buildingId=${props.router.params.id}&pageSize=2&pageNum=1`, method: 'get' }).then((res) => {
      let ResArr = res.records.slice(0, 2)
      if (ResArr.length === 1) {
        ResArr.push({})
      }
      setNewsList(ResArr || [])
    })
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  return (
    <view className='Page buildingDetail flex-v'>

      <view className='flex-item'>
        <view>
          <ScrollView scroll-y refresher-enabled={false} refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#f8f8f8'>
            <view className='PageContent'>

              {/* banner */}
              <view className='BannerContainer'>
                <view>
                  <view>
                    <Banner List={DetailInfo?.panoramaList}></Banner>
                  </view>
                </view>
              </view>

              {/* content */}
              <view className='DetailContent'>

                {/* 基本信息 */}
                <view className='BasicInfo'>
                  <BasicInfo Info={DetailInfo}></BasicInfo>
                </view>

                {/* 特价房源 */}
                <view className='SpecialPriceHouse' style={{minHeight: 0}}>
                  <SpecialPriceHouse List={DetailInfo?.specialRoomList}></SpecialPriceHouse>
                </view>

                {/* 项目动态 */}
                <view className='ProjectDynamic' style={{minHeight: 0}}>
                  <ProjectDynamic List={DetailInfo?.trendList}></ProjectDynamic>
                </view>

                {/* 置业顾问 */}
                <view className='PropertyConsultant' style={{ display: DetailInfo?.consultants?.length ? 'block' : 'none' }}>
                  <PropertyConsultant List={DetailInfo?.consultants}></PropertyConsultant>
                </view>

                {/* 位置及周边 */}
                <view className='Periphery'>
                  <Periphery Info={DetailInfo}></Periphery>
                </view>

                {/* 户型介绍 */}
                <view className='HouseTypeIntro'>
                  <HouseTypeIntro Info={DetailInfo?.buildingApartment}></HouseTypeIntro>
                </view>

                {/* 营销活动 */}
                <view className='MarketingActivity' style={{ display: ActivityList.length ? 'block' : 'none' }}>
                  <MarketingActivity List={ActivityList}></MarketingActivity>
                </view>

                {/* 直播活动 */}
                <view className='LivingActivity' style={{ display: LiveList.length ? 'block' : 'none' }}>
                  <LivingActivity List={LiveList}></LivingActivity>
                </view>

                {/* 新鲜资讯 */}
                <view className='News' style={{ display: NewsList.length ? 'block' : 'none' }}>
                  <News List={NewsList}></News>
                </view>

                {/* 相册 */}
                <view className='Pictures' style={{ display: PictureList.length ? 'block' : 'none' }}>
                  <Pictures List={PictureList}></Pictures>
                </view>

              </view>

            </view>
          </ScrollView>
        </view>
      </view>

      <view className='PageBottom'>
        <DetailBottom></DetailBottom>
      </view>

    </view>
  )
})
